import json
import argparse
from pprint import pprint
from lofar.sas.tmss.client.tmss_http_rest_client import TMSSsession
from lofar.common.datetimeutils import parseDatetime


def main_get_subtask_parset():
    parser = argparse.ArgumentParser()
    parser.add_argument("subtask_id", help="The ID of the TMSS subtask to get the parset from")
    args = parser.parse_args()

    try:
        with TMSSsession.create_from_dbcreds_for_ldap() as session:
            print(session.get_subtask_parset(args.subtask_id))
    except Exception as e:
        print(e)
        exit(1)


def main_get_subtask_predecessors():
    parser = argparse.ArgumentParser()
    parser.add_argument("subtask_id", type=int, help="The ID of the TMSS subtask to get the predecessors for")
    parser.add_argument('-s', '--state', help="only get predecessors with this state")
    args = parser.parse_args()

    try:
        with TMSSsession.create_from_dbcreds_for_ldap() as session:
            pprint(session.get_subtask_predecessors(args.subtask_id, state=args.state))
    except Exception as e:
        print(e)
        exit(1)


def main_get_subtask_successors():
    parser = argparse.ArgumentParser()
    parser.add_argument("subtask_id", type=int, help="The ID of the TMSS subtask to get the successors for")
    parser.add_argument('-s', '--state', help="only get successors with this state")
    args = parser.parse_args()

    try:
        with TMSSsession.create_from_dbcreds_for_ldap() as session:
            pprint(session.get_subtask_successors(args.subtask_id, state=args.state))
    except Exception as e:
        print(e)
        exit(1)


def main_get_subtask():
    parser = argparse.ArgumentParser()
    parser.add_argument("subtask_id", type=int, help="The ID of the TMSS subtask to get")
    args = parser.parse_args()

    try:
        with TMSSsession.create_from_dbcreds_for_ldap() as session:
            pprint(session.get_subtask(args.subtask_id))
    except Exception as e:
        print(e)
        exit(1)


def main_get_subtasks():
    parser = argparse.ArgumentParser()
    parser.add_argument('-s', '--state', help="only get subtasks with this state")
    parser.add_argument('-c', '--cluster', help="only get subtasks for this cluster")
    parser.add_argument('--start_time_less_then', help="only get subtasks with a start time less then this timestamp")
    parser.add_argument('--start_time_greater_then', help="only get subtasks with a start time greater then this timestamp")
    parser.add_argument('--stop_time_less_then', help="only get subtasks with a stop time less then this timestamp")
    parser.add_argument('--stop_time_greater_then', help="only get subtasks with a stop time greater then this timestamp")
    args = parser.parse_args()

    try:
        with TMSSsession.create_from_dbcreds_for_ldap() as session:
            result = session.get_subtasks(state=args.state,
                                          cluster=args.cluster,
                                          start_time_less_then=parseDatetime(args.start_time_less_then) if args.start_time_less_then else None,
                                          start_time_greater_then=parseDatetime(args.start_time_greater_then) if args.start_time_greater_then else None,
                                          stop_time_less_then=parseDatetime(args.stop_time_less_then) if args.stop_time_less_then else None,
                                          stop_time_greater_then=parseDatetime(args.stop_time_greater_then) if args.stop_time_greater_then else None)
            pprint(result)
    except Exception as e:
        print(e)
        exit(1)


def main_set_subtask_state():
    parser = argparse.ArgumentParser()
    parser.add_argument("subtask_id", type=int, help="The ID of the TMSS subtask to set the status on")
    parser.add_argument("state", help="The state to set")
    args = parser.parse_args()

    try:
        with TMSSsession.create_from_dbcreds_for_ldap() as session:
            changed_subtask = session.set_subtask_status(args.subtask_id, args.state)
            print("%s now has state %s, see: %s" % (changed_subtask['id'], changed_subtask['state_value'], changed_subtask['url']))
    except Exception as e:
        print(e)
        exit(1)


def main_specify_observation_task():
    """
    Ask user for parameter 'taskid' and execute API-call to specify observation
    """
    parser = argparse.ArgumentParser()
    parser.add_argument("task_id", help="The ID of the TMSS task to specify for observation")
    args = parser.parse_args()

    try:
        with TMSSsession.create_from_dbcreds_for_ldap() as session:
            result = session.specify_observation_task(args.task_id)
    except Exception as e:
        print(e)
        exit(1)


def main_schedule_subtask():
    parser = argparse.ArgumentParser()
    parser.add_argument("subtask_id", type=int, help="The ID of the TMSS subtask to be scheduled")
    args = parser.parse_args()

    try:
        with TMSSsession.create_from_dbcreds_for_ldap() as session:
            pprint(session.schedule_subtask(args.subtask_id))
    except Exception as e:
        print(e)
        exit(1)


def main_get_setting():
    parser = argparse.ArgumentParser()
    parser.add_argument("setting_name", type=str, help="The name of the TMSS setting to get")
    args = parser.parse_args()

    try:
        with TMSSsession.create_from_dbcreds_for_ldap() as session:
            pprint(session.get_setting(args.setting_name))
    except Exception as e:
        print(e)
        exit(1)


def main_set_setting():
    parser = argparse.ArgumentParser()
    parser.add_argument("setting_name", type=str, help="The name of the TMSS setting to set")
    parser.add_argument("setting_value", type=lambda s: s.lower() in ['true', 'True', '1'], # argparse is noot very good at speaking bool...
                        help="The value to set for the TMSS setting")
    args = parser.parse_args()

    try:
        with TMSSsession.create_from_dbcreds_for_ldap() as session:
            pprint(session.set_setting(args.setting_name, args.setting_value))
    except Exception as e:
        print(e)
        exit(1)
