"""
This file contains the serializers (for the elsewhere defined data models)
"""

import logging
logger = logging.getLogger(__name__)

from rest_framework import serializers
from .. import models
from .specification import RelationalHyperlinkedModelSerializer
from .widgets import JSONEditorField

class SubtaskStateSerializer(RelationalHyperlinkedModelSerializer):
    class Meta:
        model = models.SubtaskState
        fields = '__all__'


class SubtaskStateLogSerializer(RelationalHyperlinkedModelSerializer):
    class Meta:
        model = models.SubtaskStateLog
        fields = '__all__'


class SubtaskTypeSerializer(RelationalHyperlinkedModelSerializer):
    class Meta:
        model = models.SubtaskType
        fields = '__all__'


class StationTypeSerializer(RelationalHyperlinkedModelSerializer):
    class Meta:
        model = models.StationType
        fields = '__all__'


class AlgorithmSerializer(RelationalHyperlinkedModelSerializer):
    class Meta:
        model = models.Algorithm
        fields = '__all__'


class ScheduleMethodSerializer(RelationalHyperlinkedModelSerializer):
    class Meta:
        model = models.ScheduleMethod
        fields = '__all__'


class SubtaskTemplateSerializer(RelationalHyperlinkedModelSerializer):
    class Meta:
        model = models.SubtaskTemplate
        fields = '__all__'


class DefaultSubtaskTemplateSerializer(RelationalHyperlinkedModelSerializer):
    class Meta:
        model = models.DefaultSubtaskTemplate
        fields = '__all__'


class DataproductSpecificationsTemplateSerializer(RelationalHyperlinkedModelSerializer):
    class Meta:
        model = models.DataproductSpecificationsTemplate
        fields = '__all__'


class DefaultDataproductSpecificationsTemplateSerializer(RelationalHyperlinkedModelSerializer):
    class Meta:
        model = models.DefaultDataproductSpecificationsTemplate
        fields = '__all__'



class DataproductFeedbackTemplateSerializer(RelationalHyperlinkedModelSerializer):
    class Meta:
        model = models.DataproductFeedbackTemplate
        fields = '__all__'


class SubtaskSerializer(RelationalHyperlinkedModelSerializer):
    # If this is OK then we can extend API with NO url ('flat' values) on more places if required
    cluster_value = serializers.StringRelatedField(source='cluster', label='cluster_value', read_only=True)

    class Meta:
        model = models.Subtask
        fields = '__all__'
        extra_fields = ['cluster_value']

    # Create a JSON editor form to replace the simple text field based on the schema in the template that this
    # draft refers to. If that fails, the JSONField remains a standard text input.
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        try:
            self.fields['specifications_doc'] = JSONEditorField(self.instance.specifications_template.schema)
        except Exception as e:
            print('Could not initialize JSONEditorField (%s), hence no fancy JSON form. This is expected for e.g. the list view.' % e)
            # todo: Shall we use the schema for one of the default templates in this case instead?


class SubtaskInputSerializer(RelationalHyperlinkedModelSerializer):

    # Create a JSON editor form to replace the simple text field based on the schema in the template that this
    # draft refers to. If that fails, the JSONField remains a standard text input.
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        try:
            self.fields['selection_doc'] = JSONEditorField(self.instance.selection_template.schema)
        except Exception as e:
            print('Could not initialize JSONEditorField (%s), hence no fancy JSON form. This is expected for e.g. the list view.' % e)
            # todo: Shall we use the schema for one of the default templates in this case instead?

    class Meta:
        model = models.SubtaskInput
        fields = '__all__'


class SubtaskOutputSerializer(RelationalHyperlinkedModelSerializer):
    class Meta:
        model = models.SubtaskOutput
        fields = '__all__'
        #extra_fields = ['dataproducts', 'consumers']  #TODO: how can we make the inputs and outputs visible in the rest view without making them required for POSTs?


class DataproductSerializer(RelationalHyperlinkedModelSerializer):

    # Create a JSON editor form to replace the simple text field based on the schema in the template that this
    # draft refers to. If that fails, the JSONField remains a standard text input.
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        try:
            self.fields['specifications_doc'] = JSONEditorField(self.instance.specifications_template.schema)
            self.fields['feedback_doc'] = JSONEditorField(self.instance.feedback_template.schema)
        except Exception as e:
            print('Could not initialize JSONEditorField (%s), hence no fancy JSON form. This is expected for e.g. the list view.' % e)
            # todo: Shall we use the schema for one of the default templates in this case instead?

    class Meta:
        model = models.Dataproduct
        fields = '__all__'


class AntennaSetSerializer(RelationalHyperlinkedModelSerializer):
    class Meta:
        model = models.AntennaSet
        fields = '__all__'


class DataproductTransformSerializer(RelationalHyperlinkedModelSerializer):
    class Meta:
        model = models.DataproductTransform
        fields = '__all__'


class FilesystemSerializer(RelationalHyperlinkedModelSerializer):
    class Meta:
        model = models.Filesystem
        fields = '__all__'


class ClusterSerializer(RelationalHyperlinkedModelSerializer):
    class Meta:
        model = models.Cluster
        fields = '__all__'


class DataproductArchiveInfoSerializer(RelationalHyperlinkedModelSerializer):
    class Meta:
        model = models.DataproductArchiveInfo
        fields = '__all__'


class DataproductHashSerializer(RelationalHyperlinkedModelSerializer):
    class Meta:
        model = models.DataproductHash
        fields = '__all__'


