"""
A viewset extended with annotation and other common generic behaviours.

Adds the following functionality:
- Swagger API annotation
"""

from rest_framework import viewsets
from drf_yasg.utils import swagger_auto_schema
from rest_framework import mixins

class LOFARViewSet(viewsets.ModelViewSet):
    """
    If you're using format suffixes, make sure to also include
    the `format=None` keyword argument for each action.
    """

    @swagger_auto_schema(responses={403: 'forbidden'})
    def list(self, request, **kwargs):
        return super(LOFARViewSet, self).list(request, **kwargs)

    @swagger_auto_schema(responses={400: 'invalid specification', 403: 'forbidden'})
    def create(self, request, **kwargs):
        return super(LOFARViewSet, self).create(request, **kwargs)

    @swagger_auto_schema(responses={403: 'forbidden', 404: 'not found'})
    def retrieve(self, request, pk=None, **kwargs):
        return super(LOFARViewSet, self).retrieve(request, pk, **kwargs)

    @swagger_auto_schema(responses={400: 'invalid specification', 403: 'forbidden', 404: 'not found'})
    def update(self, request, pk=None, **kwargs):
        return super(LOFARViewSet, self).update(request, pk, **kwargs)

    @swagger_auto_schema(responses={400: 'invalid specification', 403: 'forbidden', 404: 'not found'})
    def partial_update(self, request, pk=None, **kwargs):
        return super(LOFARViewSet, self).partial_update(request, pk, **kwargs)

    @swagger_auto_schema(responses={403: 'forbidden', 404: 'not found'})
    def destroy(self, request, pk=None, **kwargs):
        return super(LOFARViewSet, self).destroy(request, pk, **kwargs)

class LOFARNestedViewSet(mixins.CreateModelMixin,
                                mixins.ListModelMixin,
                                #mixins.RetrieveModelMixin,
                                viewsets.GenericViewSet):
    
    @swagger_auto_schema(responses={403: 'forbidden'})
    def list(self, request, **kwargs):
        return super(LOFARNestedViewSet, self).list(request, **kwargs)

    @swagger_auto_schema(responses={400: 'invalid specification', 403: 'forbidden'})
    def create(self, request, **kwargs):
        return super(LOFARNestedViewSet, self).create(request, **kwargs)