import React, {Component} from 'react';
import ReactDOM from 'react-dom';
import 'bootstrap/dist/css/bootstrap.css';
import 'bootstrap/dist/js/bootstrap.js';

// Procedures

var headers = new Headers();
headers.append('Content-Type', 'application/json');

var api_url = '/api/'

function tmssGetList(url, component){
   console.log('Getting '+ url)
   fetch(api_url+url, {headers: headers})
     .then(response => response.json())
     .then(response => {console.log(response);
                        component.setState({items:response.results});})
     .catch(err => console.log(err))
   }

function tmssGet(url, component){
   console.log('Getting '+ url)
   fetch(api_url+url, {headers: headers})
     .then(response => response.json())
     .then(response => {console.log(response);
                        component.setState(response);})
     .catch(err => console.log(err))
   }

function tmssPost(url, data, component){
   console.log('Posting '+ url)
   fetch(api_url+url, {headers: headers, method: 'POST', body: data})
     .then(ReactDOM.render(<ProjectList />, document.getElementById('root')))
     .catch(err => console.log(err))
   }

function tmssPut(url, data, component){
   console.log('Putting '+ url)
   console.log(data)
   fetch(api_url+url, {headers: headers, method: 'PUT', body: data})
     .then(ReactDOM.render(<ProjectList />, document.getElementById('root')))
     .catch(err => console.log(err))
   }

function tmssPatch(url, data, component){
   console.log('Patching '+ url)
   console.log(data)
   fetch(api_url+url, {headers: headers, method: 'PATCH', body: data})
     .then(ReactDOM.render(<ProjectList />, document.getElementById('root')))
     .catch(err => console.log(err))
   }

function tmssDelete(url){
   console.log('Deleting '+ url)
   fetch(api_url+url, {headers: headers, method: 'DELETE'})
     .catch(err => console.log(err))
   }


// Components

const Tag = props => (
   <span className={props.tag === 'test' ? 'badge badge-primary' : 'badge badge-secondary'}>{props.tag}</span>
)

const Project = props => (
    <tr className={props.project.expert ? 'warning' : ''}>
	<td>{props.project.tags.map(
        function(currentTag, i){
            return <Tag tag={currentTag} key={i} />
        }
        )}</td>
    <td className={props.project.filler ? 'bg-success': 'bg-warning'}>{props.project.filler ? 'yes': 'no'}</td>
    <td>{props.project.cycle}</td>
    <td>{props.project.name}</td>
    <td>{props.project.priority}</td>
    <td>
        <button className="btn btn-primary" onClick={() => ReactDOM.render(<EditProject project={props.project.name}/>, document.getElementById('root'))}>Edit</button>
        <button className="btn btn-danger"onClick={() => {
                tmssDelete('project/'+props.project.name);
                    props.deleteItem(props.index);
                }}>Delete</button>
    </td>
    </tr>
)

// Main Components

class EditProject extends Component {

    constructor(props) {
        super(props);

        this.onChangeName = this.onChangeName.bind(this);
        this.onChangeDescription = this.onChangeDescription.bind(this);
        this.onChangeCycle = this.onChangeCycle.bind(this);
        this.onChangePriority = this.onChangePriority.bind(this);
        this.onChangeIsFiller = this.onChangeIsFiller.bind(this);
        this.onSubmit = this.onSubmit.bind(this);

        this.state = { 
            isnew: props.isnew,
            project: props.project,
            name: props.project,
            tags: [],
            description: 'enter description here',
            cycle: '',
            priority: '1',
            filler: false,
            trigger: false,
            private: false,
            expert: false,
        }
    }

    componentDidMount() {
        if(!this.state.isnew){
    	    tmssGet('project/'+this.state.project+'/', this);
        }
    }

    onChangeName(e) {
        this.setState({
            name: e.target.value
        });
    }

    onChangeDescription(e) {
        this.setState({
            description: e.target.value
        });
    }

    onChangeCycle(e) {
        this.setState({
            cycle: e.target.value
        });
    }

    onChangePriority(e) {
        this.setState({
            priority: e.target.value
        });
    }

    onChangeIsFiller(e) {
        this.setState({
            filler: !this.state.filler
        });
    }

    onSubmit(e) {
        e.preventDefault();
        const data = {
            name: this.state.name,
            tags: this.state.tags,
            description: this.state.description,
            cycle: this.state.cycle,
            priority: this.state.priority,
            filler: this.state.filler,
            trigger: this.state.filler,
            private: this.state.private,
            expert: this.state.expert,
        };
        if(this.state.isnew){
            tmssPost('project/', JSON.stringify(data), this)
        }else{
            tmssPut('project/'+this.props.project+'/', JSON.stringify(data), this)
        }
    }

    render() {
        return (
            <div>
                <h3 align="center">Edit Project</h3>
                <form onSubmit={this.onSubmit}>
                    <div className="form-group">
                        <label>Name: </label>
                        <input  type="text"
                                className="form-control"
                                value={this.state.name}
                                onChange={this.onChangeName}
                                />
                    </div>
                    <div className="form-group">
                        <label>Description: </label>
                        <input  type="text"
                                className="form-control"
                                value={this.state.description}
                                onChange={this.onChangeDescription}
                                />
                    </div>
                    <div className="form-group">
                        <label>Cycle: </label>
                        <input 
                                type="text" 
                                className="form-control"
                                value={this.state.cycle}
                                onChange={this.onChangeCycle}
                                />
                    </div>
                    <div className="form-group">
                        <label>
                            Priority:
                        </label>     
                        <input  className="form-control-range"
                                id="prioritySlider"
                                type="range"
                                name="prioritySlider"
                                value={this.state.priority}
                                onChange={this.onChangePriority}
                                />
                                           
                    </div>
                    <div className="form-check">
                        <input  className="form-check-input"
                                id="fillerCheckbox"
                                type="checkbox"
                                name="fillerCheckbox"
                                onChange={this.onChangeIsFiller}
                                checked={this.state.filler}
                                value={this.state.filler}
                                />
                        <label className="form-check-label" htmlFor="fillerCheckbox">
                            Filler
                        </label>                        
                    </div>

                    <br />

                    <div className="form-group">
                        <input type="submit" value="Submit" className="btn btn-primary" />
                    </div>
                </form>
            </div>
        )
    }
}

class ProjectList extends Component {

    constructor(props) {
        super(props);
        this.state = {items: []};
    }

    componentDidMount(){
        tmssGetList('project/', this);
    }

    deleteItem = (index) => {
        var itms = this.state.items;
        itms.splice(index, 1);
        this.setState( {items: itms} );
    }

    projects() {
        return this.state.items.map(
		(currentProject, i) => <Project project={currentProject} key={i} index={i} deleteItem={this.deleteItem} /> 
	);
    }

    render() {
        return (
            <div>
                <h3>Project List <button className="btn btn-primary" onClick={() => ReactDOM.render(<EditProject project={'default_name'} isnew={true} />, document.getElementById('root'))}>Create New</button></h3> 
                <table className="table table-striped table-bordered table-hover">
                    <thead>
                        <tr>
                            <th>Tags</th>
			    <th>Filler</th>
                            <th>Cycle</th>
                            <th>Name</th>
                            <th>Priority</th>
                            <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        { this.projects() }
                    </tbody>
                </table>
            </div>
        )
    }
}

export default ProjectList


