// React
import React, {Component} from 'react';
import ReactDOM from 'react-dom';

// Bootstrap
import 'bootstrap/dist/css/bootstrap.css';
import 'bootstrap/dist/js/bootstrap.js';

// JSON editor
// ...Bootstrap v3 is used by default, but for various reasons, we want v4:
import Form from 'react-jsonschema-form-bs4'; // todo: use main line "react-jsonschema-form" once it supports Bootstrap v4
// ...only supports latest out of the box, older schemas need to be passed to Form via this:
const additionalMetaSchemas = require("ajv/lib/refs/json-schema-draft-06.json");


// todo: add a check that we have an active session with the API, redirect offer login if not
var headers = new Headers();
headers.append('Content-Type', 'application/json');

var api_url = '/api/';


// Procedures   // todo: revise and put these somewhere so they can be shared by entire frontend

function tmssGetList(url, component){
   if(!url.startsWith('http')){
        url = api_url+url;
   }
   fetch(url, {headers: headers})
     .then(response => response.json())
     .then(response => {// React cannot handle deep states, so we have to stringify nested objects before setState()
                        response.results.forEach(result => {result.specifications_doc = JSON.stringify(result.specifications_doc);});
                        component.setState({items:response.results});})
     .catch(err => alert(err))
   }

function tmssGet(url, component){
   if(!url.startsWith('http')){
        url = api_url+url;
   }
   fetch(url, {headers: headers})
     .then(response => response.json())
     .then(response => {component.setState(response);
                        component.updateSchema();
                        })
     .catch(err => alert(err))
   }

function tmssGetReferenceList(url, state_name, component){
   if(!url.startsWith('http')){
        url = api_url+url;
   }
   fetch(url, {headers: headers})
                .then(response => {return response.json();})
                .then(response => {
                    var references = response.results.map((reference) => {return reference.url});
                    component.setState({
                        [state_name]: references
                    });
                 })}

function tmssPost(url, data, component){
   if(!url.startsWith('http')){
        url = api_url+url;
   }
   fetch(url, {headers: headers, method: 'POST', body: data})
     .then(ReactDOM.render(<TaskDraftList />, document.getElementById('root')))
     .catch(err => alert(err))
   }

function tmssPut(url, data, component){
   if(!url.startsWith('http')){
        url = api_url+url;
   }
   fetch(url, {headers: headers, method: 'PUT', body: data})
     .then(ReactDOM.render(<TaskDraftList />, document.getElementById('root')))
     .catch(err => alert(err))
   }

function tmssPatch(url, data, component){
   if(!url.startsWith('http')){
        url = api_url+url;
   }
   fetch(url, {headers: headers, method: 'PATCH', body: data})
     .then(ReactDOM.render(<TaskDraftList />, document.getElementById('root')))
     .catch(err => alert(err))
   }

function tmssDelete(url){
   if(!url.startsWith('http')){
        url = api_url+url;
   }
   fetch(url, {headers: headers, method: 'DELETE'})
     .catch(err => alert(err))
   }


// Components

const Tag = props => (
   <span className={props.tag === 'test' ? 'badge badge-primary' : 'badge badge-secondary'}>{props.tag}</span>
)

const TaskDraft = props => (
    <tr>
	<td>{props.task_draft.tags.map(
        function(currentTag, i){
            return <Tag tag={currentTag} key={i} />
        }
        )}</td>
    <td>{props.task_draft.name}</td>
    <td>{props.task_draft.description}</td>
    <td>{props.task_draft.scheduling_unit_draft}</td>
    <td>{props.task_draft.specifications_template}</td>
    <td>{props.task_draft.specifications_doc}</td>
    <td>
        <button className="btn btn-primary" onClick={() => ReactDOM.render(<EditTaskDraft id={props.task_draft.url}/>, document.getElementById('root'))}>Edit</button>
        <button className="btn btn-danger"onClick={() => {
                tmssDelete(props.task_draft.url);
                    props.deleteItem(props.index);
                }}>Delete</button>
    </td>
    </tr>
)

// Main Components

class EditTaskDraft extends Component {

    constructor(props) {
        super(props);

        this.onChangeName = this.onChangeName.bind(this);
        this.onChangeDescription = this.onChangeDescription.bind(this);
        this.onChangeSpecificationsDoc = this.onChangeSpecificationsDoc.bind(this);
        this.onChangeCopies = this.onChangeCopies.bind(this);
        this.onChangeCopyReason = this.onChangeCopyReason.bind(this);
        this.onChangeSchedulingUnitDraft = this.onChangeSchedulingUnitDraft.bind(this);
        this.onChangeSpecificationsTemplate = this.onChangeSpecificationsTemplate.bind(this);
        this.onSubmit = this.onSubmit.bind(this);
        this.updateSchema = this.updateSchema.bind(this);

        this.state = {
            isnew: props.isnew,
            id: props.id,
            schema: {},
            templates: [],
            drafts: [],
            // default values for new item (state gets overwritten by componentDidMount for non-new):
            name: "my_name",
            tags: ["test"],
            description: 'my_description',
            specifications_doc: {
                  "stations": [
                    {
                      "group": "ALL",
                      "min_stations": 1
                    }
                  ],
                  "antenna_set": "HBA_DUAL",
                  "filter": "HBA_110_190",
                  "analog_pointing": {
                    "direction_type": "J2000",
                    "angle1": 42,
                    "angle2": 42
                  },
                  "beams": [
                    {
                      "name": "calibrator",
                      "digital_pointing": {
                        "direction_type": "J2000",
                        "angle1": 24,
                        "angle2": 24
                      },
                      "subbands": [
                        1,
                        2,
                        3
                      ]
                    }
                  ]
                  },
            copies: null,
            copy_reason: null,
            scheduling_unit_draft: api_url + "scheduling_unit_draft/1/",
            specifications_template: api_url + "task_template/1/",
            task_blueprints: [],
            produced_by: [],
            consumed_by: []
        }
    }

    componentDidMount() {
        if(!this.state.isnew){
            // update state with db info of the represented entity
    	    tmssGet(this.state.id, this);
        }
        //update list  entities for UI elements
    	tmssGetReferenceList('task_template/', 'templates', this);
    	tmssGetReferenceList('scheduling_unit_draft/', 'drafts', this);
    }

    updateSchema(){
        fetch(this.state.specifications_template, {headers: headers})
            .then(response => response.json())
            .then(response => {
                this.setState({
                    schema: response.schema
                    });
                })
    }

    onChangeName(e) {
        this.setState({
            name: e.target.value
        });
    }

    onChangeDescription(e) {
        e.preventDefault()
        this.setState({
            description: e.target.value
        });
    }

    onChangeSpecificationsDoc(e) {
        this.setState({
            specifications_doc: e.formData
        });
    }

    onChangeCopies(e) {
        this.setState({
            copies: e.target.value
        });
    }

    onChangeCopyReason(e) {
        this.setState({
            copy_reason: e.target.value
        });
    }

    onChangeSchedulingUnitDraft(e) {
        this.setState({
            scheduling_unit_draft: e.target.value
        });
    }

    onChangeSpecificationsTemplate(e) {
        this.setState({
            specifications_template: e.target.value
        });
        this.updateSchema();
    }

    onSubmit(e) {
        e.preventDefault();
        const data = {
            name: this.state.name,
            tags: this.state.tags,
            description: this.state.description,
            specifications_doc: this.state.specifications_doc,
            copies: this.state.copies,
            copy_reason: this.state.copy_reason,
            scheduling_unit_draft: this.state.scheduling_unit_draft,
            specifications_template: this.state.specifications_template,
            task_blueprints: this.state.task_blueprints,
            produced_by: this.state.produced_by,
            consumed_by: this.state.consumed_by
        };
        if(this.state.isnew){
            tmssPost('task_draft/', JSON.stringify(data), this);
        }else{
            tmssPatch(this.props.id, JSON.stringify(data), this);
        }
    }

    render() {
        return (
            <div>
                <h3 align="center">Edit Task Draft</h3>
                <form onSubmit={this.onSubmit}>
                    <div className="form-group">
                        <label>Name: </label>
                        <input  type="text"
                                className="form-control"
                                value={this.state.name}
                                onChange={this.onChangeName}
                                />
                    </div>
                    <div className="form-group">
                        <label>Description: </label>
                        <input  type="text"
                                className="form-control"
                                value={this.state.description}
                                onChange={this.onChangeDescription}
                                />
                    </div>
                    <div className="form-group">
                        <label>Copies: </label>
                        <input
                                type="text"
                                className="form-control"
                                value={this.state.copies}
                                onChange={this.onChangeCopies}
                                />
                    </div>
                    <div className="form-group">
                        <label>CopyReason: </label>
                        <input
                                type="text"
                                className="form-control"
                                value={this.state.copy_reason}
                                onChange={this.onChangeCopyReason}
                                />
                    </div>
                    <div className="form-group">
                        <label>SchedulingUnitDraft: </label>
                        <select
                                className="form-control"
                                value={this.state.scheduling_unit_draft}
                                onChange={this.onChangeSchedulingUnitDraft}
                                >
                                {this.state.drafts.map((opt) => {return <option key={opt} value={opt}>{opt}</option>;})}
                        </select>
                    </div>
                    <div className="form-group">
                        <label>SpecificationsTemplate: </label>
                        <select
                                className="form-control"
                                value={this.state.specifications_template}
                                onChange={this.onChangeSpecificationsTemplate}
                                >
                                {this.state.templates.map((opt) => {return <option key={opt} value={opt}>{opt}</option>;})}
                        </select>
                    </div>
                    <div className="form-group">
                        <label>SpecificationsDoc: </label>
                          <Form className="jsonform"
                            schema={this.state.schema}
                            additionalMetaSchemas={[additionalMetaSchemas]}
                            liveValidate={true}
                            show_opt_in={true}
                            formData={this.state.specifications_doc}
                            onChange={this.onChangeSpecificationsDoc} />
                    </div>
                    <br />

                    {/*
                    We get a submit button from the JSONEditor, so we don't need it here.
                    todo: It would be cleaner to use our own and hide away the JSONeditor one...
                    <div className="form-group">
                            <input type="submit" value="Submit" className="btn btn-primary" />
                    </div>
                    */}
                </form>
            </div>
        )
    }
}

class TaskDraftList extends Component {

    constructor(props) {
        super(props);
        this.state = {items: []};
    }

    componentDidMount(){
        tmssGetList('task_draft/', this);
    }

    deleteItem = (index) => {
        var itms = this.state.items;
        itms.splice(index, 1);
        this.setState( {items: itms} );
    }

    task_drafts() {
        return this.state.items.map(
		(currentTaskDraft, i) => <TaskDraft task_draft={currentTaskDraft} key={i} index={i} deleteItem={this.deleteItem} />
	);
    }

    render() {
        return (
            <div>
                <h3>Task Draft List <button className="btn btn-primary" onClick={() => ReactDOM.render(<EditTaskDraft id={'dummy_id'} isnew={true} />, document.getElementById('root'))}>Create New</button></h3>
                <table className="table table-striped table-bordered table-hover">
                    <thead>
                        <tr>
                            <th>Tags</th>
                            <th>Name</th>
                            <th>Description</th>
                            <th>SchedulingUnitDraft</th>
                            <th>SpecificationsTemplate</th>
			                <th>SpecificationsDoc</th>
                            <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        { this.task_drafts() }
                    </tbody>
                </table>
            </div>
        )
    }
}

export default TaskDraftList

